Description Usage Arguments Details Value Examples
Event names serve as an unique event in SPM. This will merge agent and agent_detail into a new column, eventName Here, each attribute of an event type is stated in the event name. Events with continuous values will first discretized. (e.g., "tumorINCR", tumor volume is the event from agent column, and INCR is the attribute converted from agent_detail column.)
1 | createEventNames(event, tType, removeChemo)
|
tType |
char, shortcut for type of tumor volume information |
event: |
dataframe, all events across all patients, each row is an event, returned from 'getData' in 'getData.R' |
removeChemo: |
bool, remove chemo event types |
event contains events as rows and at least the following columns:
iois patient id, char
agent event type, char
agent_detail event attribute, char
startdate event start date in the format 'YYYY-MM-DD', char
enddate event end date in the format 'YYYY-MM-DD', char
eventID event id
eventName distinct names for an event (e.g., mentalStatus0: agent is mental status, agent_detail is 0)
event: dataframe, cleaned and formated information that is ammendable to SPM
1 2 3 4 5 6 7 8 9 10 11 12 13 | data("fake_data")
events <- fake_data$events
events$startdate <- as.Date(as.character(events$startdate), format='%Y-%m-%d')
events$enddate <- as.Date(as.character(events$enddate), format='%Y-%m-%d')
cleaned <- removeData(events)
cleaned <- resetEventIDsToDays(cleaned)
cleaned <- removePreRadiation(cleaned)
cleaned <- createEventNames(event=cleaned,
tType='r',
removeChemo=T)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.