Description Usage Arguments Details Value See Also
Perform cross-validation on training partition.
1 2 3 4 |
data |
dataframe, rows are samples, cols are features plus some metadata not meant for modeling and will be removed |
formula |
char or formula object |
labelName |
char, column name of binary label |
lasso |
logical, whether to use lasso regularization |
llength |
num, number of lambdas to consider up to |
lmax |
num, maximum lambda to consider, cannot be NULL if lambda is NULL |
predictors |
char, names of columns in |
needToRemove |
char, names of columns in |
createModelMatrix |
logical, call |
metric |
char, see |
seed |
int, seed for split |
folds |
number of folds |
verbose |
logical, True for print, False for silence |
Removes rows for which a column is NA.
folds a list of arrays indicating row
position integers corresponding to fold split
groupKFold,
getPatIDs,
getClassLabels,
getData
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.