Description Usage Arguments Details Value
Get patient event and survival data from a database
getEventData: get event data from eventTable in database
getSurvData: get patient survival days and survival status from personTable in database
getDemographics: get patient demographics and two biomarkers from personTable in database
1 2 3 4 5 6 7 | getData(database, eventTable, personTable)
getEventData(database, eventTable)
getSurvData(database, personTable)
getDemographics(database, personTable)
|
database |
a MySQL database, where connection is
authenticated through a configuration file with group named |
eventTable |
an event-based table in
|
personTable |
a patient-based table in
|
Note: tumor lateriality and location is searched for in agent_detail regardless of agent/event type.
getData returns a named list containing two dataframes, 'person' for patient data
(returned by getSurvData) and 'event' for event data (returned by getEventData)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.