Description Usage Arguments Value See Also
Patients are first split into training and testing partitions. Next, samples with NA features will be removed. Then, training partition is split for cross-validation so that no patient has events in both validation and training. Both partitions are prepped for logit fitting and cross-validation is run.
1 2 3 |
data |
dataframe, rows are samples, cols are features plus some metadata not meant for modeling and will be removed |
formula |
char or formula object |
labelName |
char, column name of binary label |
lasso |
logical, whether to use lasso regularization |
llength |
num, number of lambdas to consider up to |
lmax |
num, maximum lambda to consider, cannot be NULL if lambda is NULL |
predictors |
char, names of columns in |
needToRemove |
char, names of columns in |
createModelMatrix |
logical, call |
metric |
char, see |
seed |
int, seed for split |
folds |
number of folds |
list of logit fits, averaged cross-validation results (if cvReps > 1), and test data partition
(one that is formated like training data and is ready to be called by subsequent trained model)
prepLogitData,
getCV,
getPerformanceNames
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.